AppticsDioInterceptor class

A Dio-compatible interceptor that tracks API calls via AppticsApiTracker.

Constructors

AppticsDioInterceptor({AppticsApiTracker? tracker})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tracker AppticsApiTracker
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(dynamic error, dynamic handler) → void
Call this from Dio's onError interceptor handler.
onRequest(dynamic options, dynamic handler) → void
Call this from Dio's onRequest interceptor handler.
onResponse(dynamic response, dynamic handler) → void
Call this from Dio's onResponse interceptor handler.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited