AppticsFlutter class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
addEvent (String ? event , String ? group , {Map <String , dynamic > ? properties })
→ Future <void >
Use this method to track an event. Make sure you give meaningful names for events and their groups
@param eventName name of the Occuring Event
@param eventGroup name of the Group
@param properties any object that is conforms to JSON Encoding
flush ()
→ Future <void >
getTrackingState ()
→ Future <TrackingState ? >
Returns the enum TrackingState for the current user:
noTracking,
usageAndCrashTrackingWithPII,
onlyUsageTrackingWithPII,
onlyCrashTrackingWithPII,
usageAndCrashTrackingWithoutPII,
onlyUsageTrackingWithoutPII,
onlyCrashTrackingWithoutPII
@return TrackingState
getUserProperties ()
→ Future <Map <String , dynamic > ? >
Returns the current user's properties as a Map.
Available from Apptics Android SDK 0.3.9+.
isUserLoggedIn ()
→ Future <bool ? >
Returns the logged-in status of the user associated with the device.
@return true if logged in else false.
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openPrivacySettings ()
→ Future <void >
This method opens the screen where the user can change their analytic privacy settings.
This method will show the user the privacy options that are built into the Apptics SDK.
registerPushNotification ()
→ Future <void >
removeUser (String userId , [String ? groupId ])
→ Future <void >
screenAttached (String screenName )
→ Future <void >
Use this method to track the attached screen.
@param screen_name String (Enter the name of the screen you want to track)
screenDetached (String screenName )
→ Future <void >
Use this method to track the screen that is being detached.
@param screen_name String (Enter the name of the screen you want to track)
setDefaultLanguage (String lang )
→ Future <void >
Use this method to set the language for the Analytics SDK. If the language is not found in the resource bundle, the default language will be selected.
@param lang (code) String.
setPushNotificationListener ({required dynamic onMessageReceived (Map <String , dynamic > ), required dynamic onNotificationClick (String ? , String ? ), required dynamic onNotificationActionClick (String , String ? , String ? ) })
→ Future <void >
setTrackingState (TrackingState state )
→ Future <void >
Set tracking state for the current user.
@param state TrackingState
setUser (String ? userId , [String ? groupId ])
→ Future <void >
Specify a user identifier which will be used to identify the user in the future. We recommend you use a unique userID.
setUserWithProperty (String userId , {String ? groupId , AppticsUserProperty ? props })
→ Future <void >
Set the current user with optional group ID and user properties.
User properties like email will be used for Feedback user identification.
startService ()
→ Future <void >
toString ()
→ String
A string representation of this object.
inherited