send method
Sends an HTTP request and asynchronously returns the response.
Implementers should call BaseRequest.finalize to get the body of the
request as a ByteStream. They shouldn't make any assumptions about the
state of the stream; it could have data written to it asynchronously at a
later point, or it could already be closed when it's returned. Any
internal HTTP errors should be wrapped as ClientExceptions.
Implementation
@override
Future<http.StreamedResponse> send(http.BaseRequest request) async {
final trackIdFuture = _tracker.startApiTracking(
url: request.url.toString(),
method: request.method,
);
try {
final response = await _inner.send(request);
trackIdFuture.then((trackId) {
_tracker.endApiTracking(
trackId: trackId,
statusCode: response.statusCode,
);
});
return response;
} catch (e) {
trackIdFuture.then((trackId) {
_tracker.endApiTracking(
trackId: trackId,
errorMessage: e.toString(),
);
});
rethrow;
}
}